@@ -80,7 +80,9 @@ class DBConnect:
             )
 
     def does_it_exist(self, docu: dict) -> bool:
-        count = self.mongo_collection.count_documents(docu)
+        deep_docu = copy.deepcopy(docu)  # 深拷贝
+        deep_docu = handle_db_id(deep_docu)
+        count = self.mongo_collection.count_documents(deep_docu)
         if count != 0:
             return True
         else:
